==> owncloud-10.0.3.tgz: owncloud/apps/federatedfilesharing/l10n/he.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "שיתוף מאוגד",
    "Invalid Federated Cloud ID" : "זיהוי ענן מאוגד לא חוקי",
    "Sharing %s failed, because this item is already shared with %s" : "שיתוף %s נכשל, כיוון שפריט זה כבר משותף עם %s",
    "Not allowed to create a federated share with the same user" : "אסור ליצור שיתוף מאוגד עם אותו משתמש",
    "File is already shared with %s" : "הקובץ כבר משותף עם %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "שיתוף %s נכשל, לא ניתן לאתר %s, ייתכן שהשרת לא ניתן להשגה כרגע.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "קבלת \"/%3$s\" כשיתוף מרוחק מ- %1$s (בשם %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "קבלת \"/%3$s\" כשיתוף מרוחק מ- %1$s",
    "Accept" : "אישור",
    "Decline" : "סירוב",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "שיתוף איתי באמצעות מספר זהות שרת ה- #ownCloud המאוגד שלי, ניתן לראות %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "שיתוף איתי באמצעות מספר זהות שרת ה- #ownCloud המאוגד שלי",
    "Federated Cloud Sharing" : "ענן שיתוף מאוגד",
    "Open documentation" : "תיעוד פתוח",
    "Allow users on this server to send shares to other servers" : "מאפשר למשתמשים בשרת זה לשלוח שיתופים לשרתים אחרים",
    "Allow users on this server to receive shares from other servers" : "מאפשר למשתמשים בשרת זה לקבל שיתופים משרתים אחרים",
    "Federated Cloud" : "ענן מאוגד",
    "Your Federated Cloud ID:" : "מספר זיהוי הענן המאוגד שלך:",
    "Share it:" : "שיתוף שלו:",
    "Add to your website" : "הוספה לאתר האינטרנט שלך",
    "Share with me via ownCloud" : "שיתוף איתי באמצעות ownCloud",
    "HTML Code:" : "קוד HTML:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/he.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "שיתוף מאוגד",
    "Invalid Federated Cloud ID" : "זיהוי ענן מאוגד לא חוקי",
    "Sharing %s failed, because this item is already shared with %s" : "שיתוף %s נכשל, כיוון שפריט זה כבר משותף עם %s",
    "Not allowed to create a federated share with the same user" : "אסור ליצור שיתוף מאוגד עם אותו משתמש",
    "File is already shared with %s" : "הקובץ כבר משותף עם %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "שיתוף %s נכשל, לא ניתן לאתר %s, ייתכן שהשרת לא ניתן להשגה כרגע.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "קבלת \"/%3$s\" כשיתוף מרוחק מ- %1$s (בשם %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "קבלת \"/%3$s\" כשיתוף מרוחק מ- %1$s",
    "Accept" : "אישור",
    "Decline" : "סירוב",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "שיתוף איתי באמצעות מספר זהות שרת ה- #ownCloud המאוגד שלי, ניתן לראות %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "שיתוף איתי באמצעות מספר זהות שרת ה- #ownCloud המאוגד שלי",
    "Federated Cloud Sharing" : "ענן שיתוף מאוגד",
    "Open documentation" : "תיעוד פתוח",
    "Allow users on this server to send shares to other servers" : "מאפשר למשתמשים בשרת זה לשלוח שיתופים לשרתים אחרים",
    "Allow users on this server to receive shares from other servers" : "מאפשר למשתמשים בשרת זה לקבל שיתופים משרתים אחרים",
    "Federated Cloud" : "ענן מאוגד",
    "Your Federated Cloud ID:" : "מספר זיהוי הענן המאוגד שלך:",
    "Share it:" : "שיתוף שלו:",
    "Add to your website" : "הוספה לאתר האינטרנט שלך",
    "Share with me via ownCloud" : "שיתוף איתי באמצעות ownCloud",
    "HTML Code:" : "קוד HTML:",
    "Add to your ownCloud" : "הוספה ל- ownCloud שלך"
},
"nplurals=2; plural=(n != 1);");
